@@ -1,4 +1,4 @@
-//@line 40 "/builds/slave/lorentz-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
+//@line 40 "/builds/moz2_slave/mozilla-1.9.2-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
 
@@ -192,10 +192,10 @@ function wrapToolbarItems()
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
 
-//@line 234 "/builds/slave/lorentz-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
+//@line 234 "/builds/moz2_slave/mozilla-1.9.2-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
         if (item.firstChild && item.firstChild.localName == "menubar")
           continue;
-//@line 237 "/builds/slave/lorentz-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
+//@line 237 "/builds/moz2_slave/mozilla-1.9.2-macosx-xulrunner/build/toolkit/content/customizeToolbar.js"
 
         if (isToolbarItem(item)) {
           var wrapper = wrapToolbarItem(item);
@@ -424,7 +424,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect its
+ * is stripped of any attributes that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -444,13 +444,14 @@ function cleanUpItemForPalette(aItem, aWrapper)
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
-  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
   aItem.removeAttribute("width");
 
-  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
-    aItem.firstChild.removeAttribute("observes");
+  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
+    aNode.removeAttribute("disabled");
+  });
 
+  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
